import mtoa.ui.ae.templates as templates
import maya.cmds as cmds
import mtoa.ui.ae.utils as aeUtils
from mtoa.ui.ae.shaderTemplate import ShaderAETemplate
class AElentil_cameraTemplate(templates.AttributeTemplate):
	def filenameEditBokehInput(self, mData) :
		attr = self.nodeAttr('bokehImagePath')
		cmds.setAttr(attr,mData,type='string')

	def LoadFilenameButtonPushBokehInput(self, *args):
		basicFilter = 'All Files (*.*)'
		ret = cmds.fileDialog2(fileFilter=basicFilter, dialogStyle=2, cap='Select file location',fm=0)
		if ret is not None and len(ret):
			self.filenameEditBokehInput(ret[0])
			cmds.textFieldButtonGrp('filenameBokehGrpInput', edit=True, text=ret[0])

	def filenameNewBokehInput(self, nodeName):
		path = cmds.textFieldButtonGrp('filenameBokehGrpInput', label='Bokeh Image', changeCommand=self.filenameEditBokehInput, width=300)
		cmds.textFieldButtonGrp(path, edit=True, text=cmds.getAttr(nodeName))
		cmds.textFieldButtonGrp(path, edit=True, buttonLabel='...', buttonCommand=self.LoadFilenameButtonPushBokehInput)

	def filenameReplaceBokehInput(self, nodeName):
		cmds.textFieldButtonGrp('filenameBokehGrpInput', edit=True, text=cmds.getAttr(nodeName) )

	def setup(self):


		self.beginLayout("General", collapse=False)
		self.addControl("camera_type", label="Camera Type", annotation="Thinlens is super fast, Polynomial optics is super accurate.")
		self.addControl("bidir_sample_mult", label="Samples Multiplier", annotation="A multiplier on the bidirectional sample count. The actual sample count is adaptive over the image (modulated by screenspace area of the bokeh, etc)")
		self.addControl("units", label="Scene Units", annotation="Use Centimeter in Maya, use Meter for Houdini (default universe scaling)")
		self.addControl("sensor_width", label="Sensor Width (mm)", annotation="Default is the width of a full frame sensor [36 mm]. Adjustments to the sensor size result in different effective focal lengths of the lens.")
		self.addControl("enable_dof", label="Enable Depth of Field", annotation="Disabling makes the aperture an infinitesimal point.")
		self.addControl("fstop", label="F-Stop", annotation="The f-stop is a dimensionless number that is a quantitative measure of lens speed. Practically, it is the ratio of the distance from the lens to the point where the focused light converges (the focal length) over the diameter of the aperture.")
		self.addControl("focus_dist", label="Focus Distance (cm)", annotation="Distance between the lens and the focal plane in centimeter.")
		self.addControl("aperture_blades_lentil", label="Aperture Blades", annotation="Number of aperture blades. < 3 is perfectly circular.")
		self.addControl("exp", label="Exposure", annotation="Exposure Multiplier")
		self.endLayout() # END General
		self.beginLayout("Polynomial Optics", collapse=False)
		self.addControl("lens_model", label="Lens Model", annotation="There are many different lenses to choose from, each with multiple focal lengths pre-computed. Each lens has its own characteristics. See the online documentation for previews of all lens models.")
		self.addControl("wavelength", label="Wavelength (nm)", annotation="Wavelength in Nanometers. The Polynomial Optics model is spectral, but since Arnold is an RGB renderer, we leave trace every ray with the same wavelength.")
		self.addControl("extra_sensor_shift", label="Additional Sensor shift (mm)", annotation="The autofocus system is more complicated for polynomial optics than for the thinlens model. This option allows you to slightly push the sensor forward and backward to fine-tune the focus (if needed!).")
		self.endLayout() # END Polynomial Optics
		self.beginLayout("Thin Lens", collapse=False)
		self.addControl("focal_length_lentil", label="Focal Length (mm)", annotation="Distance between the lens and the point at which the light converges in millimeters.")
		self.addControl("optical_vignetting", label="Optical Vignetting", annotation="Sometimes referred to as the cat-eye effect, this is a lens imperfection that is not caused by the glass but by the outer edge of the lens housing, also known as the exit aperture.")
		self.addControl("abb_spherical", label="Aberration (spherical)", annotation="Due to the spherical nature of lenses, light cannot be focused onto exactly a singular point. A value of 0.5 means no spherical aberration.")
		self.addControl("abb_distortion", label="Aberration (distortion)", annotation="Emperical distortion aberration. Note that lenses with a short focal length will generally exhibit greater amounts of distortion. We chose to not automatically model this, but rather keep it up to the user for greater artistic control.")
		self.addControl("abb_coma", label="Aberration (coma)", annotation="Emperical coma aberration. There may be slight discrepancies between forward and bidirectional results.")
		self.addControl("bokeh_circle_to_square", label="Square Bokeh", annotation="Sometimes for artistic purposes you might want to make the bokeh a little more square. This can sometimes happen with anamorphic lenses. 0 is a perfectly circular highlight, 1 is perfectly square.")
		self.addControl("bokeh_anamorphic", label="Anamorphic Squeeze", annotation="This scales the bokeh along the x-axis.")
		self.endLayout() # END Thin Lens
		self.beginLayout("Bokeh Texture", collapse=True)
		self.addControl("bokeh_enable_image", label="Enable Texture", annotation="This option replaces the circular/polygonal aperture with a texture-based one.")
		self.addControl("bokeh_image_path", label="Filepath", annotation="Supply small-ish images. The visual quality will not increase much above 250x250, but the pre-computation time will.")
		self.endLayout() # END Bokeh Texture
		self.beginLayout("Bidirectional", collapse=True)
		self.addControl("vignetting_retries", label="Vignetting Quality", annotation="Since we are modeling real lenses, it is possible that the light ray hits the housing of the lens. If this happens, a new light ray is sent out in a different direction.")
		self.addControl("abb_chromatic", label="Aberration (chromatic)", annotation="Different wavelengths focus at different distances. This aberration only applies to bidirectional-enabled renders.")
		self.addControl("abb_chromatic_type", label="Chromatic shift", annotation="Choose between colour fringes.")
		self.addControl("bidir_add_energy", label="Additional Energy", annotation="Sometimes for artistic reasons, you might want to boost the intensity of the bokeh a bit.")
		self.addControl("bidir_add_energy_minimum_luminance", label="Additional Energy Treshold", annotation="Only samples with a value above this parameter will be considered.")
		self.addControl("bidir_add_energy_transition", label="Additional Energy Treshold Transition", annotation="This allows for a smooth transition, so that the additional energy does not flicker when the treshold is reached.")
		self.addControl("enable_bidir_transmission", label="Enable for transmitted surfaces", annotation="WARNING: this should not be used, unless in very specific circumstances. For example, when you might be rendering a set of led lights which are behind a transmissive surface, but where the depth information is practically the same.")
		self.addControl("enable_skydome", label="Enable Skydome Redistribution", annotation="Enables redistribution for the skydome. Due to the usual high-brightness of HDRIs it might be desirable to disable this parameter.")
		self.endLayout() # END Bidirectional


templates.registerTranslatorUI(AElentil_cameraTemplate, "camera", "lentil_camera")
